==> bootstrap-react-2.1.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { render } from 'react-dom';
import { HashRouter as Router, Route } from 'react-router-dom';
import { Provider } from 'react-redux';
import composeReducer from './compose-reducers';
import PageProxy from './page-proxy';
import configureStore from './configure-store';

var Bootstrap =
/*#__PURE__*/
function () {
  function Bootstrap() {}

  var _proto = Bootstrap.prototype;

  _proto.getMountTarget = function getMountTarget(node) {
    if (node === void 0) {
      node = 'bsMain';
    }

    if (this.mountTarget instanceof HTMLElement) return this.mountTarget;
    if (node instanceof HTMLElement) return node;

    if (typeof node === 'string') {
      return document.querySelector(node);
    }

    throw new Error('挂载点即不是dom对象，也不是querySelector可选择的字符串，请检测项目配置');
  }
  /**
   *
   * @param {function | object} options.reducer - redux reducer
   * @param {string | HTMLElement} options.el - 应用的挂载点
   * @param {function} options.afterCreateStore - 创建完store之后的回调
   * @param {reduxMiddleware[]} options.middlewares - redux中间件
   */
  ;

  _proto.config = function config(options) {
    this.reduxStore = this.reduxStore || configureStore(options);
    this.mountTarget = this.getMountTarget(options.el);
    this.LoadingComp = options.loadingComp;
    this.ErrorComp = options.errorComp;
  };

  _proto.replaceReducer = function replaceReducer(reducer) {
    this.reduxStore.replaceReducer(composeReducer(reducer));
  };

  _proto.start = function start() {
    var _this = this;

    render(React.createElement(Provider, {
      store: this.reduxStore
    }, React.createElement(Router, null, React.createElement(Route, {
      path: "*",
      render: function render(props) {
        return React.createElement(PageProxy, _extends({
          LoadingComp: _this.LoadingComp,
          ErrorComp: _this.ErrorComp
        }, props));
      }
    }))), this.mountTarget);
  };

  return Bootstrap;
}();

var app = new Bootstrap();
export { app as default };

if (module.hot) {
  module.hot.accept('./page-proxy', function () {
    app.start();
  });
}

==> bootstrap-react-2.1.2.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { render } from 'react-dom';
import { HashRouter as Router, Route } from 'react-router-dom';
import { Provider } from 'react-redux';
import composeReducer from './compose-reducers';
import PageProxy from './page-proxy';
import configureStore from './configure-store';

var Bootstrap =
/*#__PURE__*/
function () {
  function Bootstrap() {}

  var _proto = Bootstrap.prototype;

  _proto.getMountTarget = function getMountTarget(node) {
    if (node === void 0) {
      node = 'bsMain';
    }

    if (this.mountTarget instanceof HTMLElement) return this.mountTarget;
    if (node instanceof HTMLElement) return node;

    if (typeof node === 'string') {
      return document.querySelector(node);
    }

    throw new Error('挂载点即不是dom对象，也不是querySelector可选择的字符串，请检测项目配置');
  }
  /**
   * @param {function | object} options.reducer - redux reducer 必须
   * @param {string | HTMLElement} options.el - 应用的挂载点 可选
   * @param {function} options.afterCreateStore - 创建完store之后的回调 可选
   * @param {reduxMiddleware[]} options.middlewares - redux中间件 可选
   * @param {ReactComponent} options.layout - 布局组件 可选
   * @param {ReactComponent} options.loadingComp - 加载中显示的组件 可选
   * @param {ReactComponent} options.errorComp - 出错后显示的组件 可选
   */
  ;

  _proto.config = function config(options) {
    this.reduxStore = this.reduxStore || configureStore(options);
    this.mountTarget = this.getMountTarget(options.el);
    this.loadingComp = options.loadingComp;
    this.errorComp = options.errorComp;
    this.layout = options.layout;
  };

  _proto.replaceReducer = function replaceReducer(reducer) {
    this.reduxStore.replaceReducer(composeReducer(reducer));
  };

  _proto.start = function start() {
    var _this = this;

    render(React.createElement(Provider, {
      store: this.reduxStore
    }, React.createElement(Router, null, React.createElement(Route, {
      path: "*",
      render: function render(props) {
        return React.createElement(PageProxy, _extends({
          LoadingComp: _this.loadingComp,
          ErrorComp: _this.errorComp,
          Layout: _this.layout
        }, props));
      }
    }))), this.mountTarget);
  };

  return Bootstrap;
}();

var app = new Bootstrap();
export { app as default };

if (module.hot) {
  module.hot.accept('./page-proxy', function () {
    app.start();
  });
}
